@@ -1,11 +1,11 @@
 import os
 
 import requests
+import subprocess
 
 from nose_launchable.log import logger
 from nose_launchable.version import __version__
 
-
 class LaunchableClientFactory:
     BASE_URL_KEY = "LAUNCHABLE_BASE_URL"
     TOKEN_KEY = "LAUNCHABLE_TOKEN"
@@ -16,7 +16,7 @@ class LaunchableClientFactory:
     def prepare(cls):
         url, org, wp, token = cls._parse_options()
 
-        return LaunchableClient(url, org, wp, token, requests)
+        return LaunchableClient(url, org, wp, token, requests, subprocess)
 
     @classmethod
     def _parse_options(cls):
@@ -35,12 +35,13 @@ class LaunchableClientFactory:
 class LaunchableClient:
     CLIENT_NAME = "nose-launchable"
 
-    def __init__(self, base_url, org_name, workspace_name, token, http):
+    def __init__(self, base_url, org_name, workspace_name, token, http, process):
         self.base_url = base_url
         self.org_name = org_name
         self.workspace_name = workspace_name
         self.token = token
         self.http = http
+        self.process = process
         self.build_number = None
         self.test_session_id = None
 
@@ -63,14 +64,14 @@ class LaunchableClient:
 
         self.test_session_id = response_body['id']
 
-    def infer(self, test):
+    def reorder(self, test):
         url = "{}/intake/organizations/{}/workspaces/{}/inference".format(
             self.base_url,
             self.org_name,
             self.workspace_name
         )
 
-        request_body = self._infer_request_body(test)
+        request_body = self._reorder_request_body(test)
 
         logger.debug("Request body: {}".format(request_body))
 
@@ -83,6 +84,27 @@ class LaunchableClient:
 
         return response_body
 
+    def subset(self, test_names, target):
+        url = "/test_sessions/{}".format(self.test_session_id)
+
+        proc = self.process.run(
+            ['launchable', 'subset', '--session', url, '--target', target + '%', 'file'],
+            input="\n".join(test_names),
+            encoding='utf-8',
+            stdout=self.process.PIPE,
+            stderr=self.process.PIPE
+        )
+
+        if proc.returncode != 0:
+            raise RuntimeError("launchable subset command fails. stdout: {}, stderr: {}", proc.stdout, proc.stderr)
+
+        # launchable subset command returns a list of test names splitted by \n
+        order = proc.stdout.rstrip("\n").split("\n")
+
+        logger.debug("Subset test order: {}".format(order))
+
+        return order
+
     def upload_events(self, events):
         url = "{}/intake/organizations/{}/workspaces/{}/builds/{}/test_sessions/{}/events".format(
             self.base_url,
@@ -106,7 +128,7 @@ class LaunchableClient:
             'Authorization': 'Bearer {}'.format(self.token)
         }
 
-    def _infer_request_body(self, test):
+    def _reorder_request_body(self, test):
         return {
             "test": test,
             "session": {"id": self.test_session_id, "subject": self.build_number, "flavors": {}},
